@@ -22,8 +22,8 @@ import siputils
 
 
 # Initialise the globals.
-sip_version = 0x040201
-sip_version_str = "4.2.1"
+sip_version = 0x040302
+sip_version_str = "4.3.2"
 qt_version = 0
 qt_edition = ""
 qt_winconfig = ""
@@ -43,6 +43,7 @@ default_platform = None
 # Command line options.
 opt_platform = None
 opt_qtlib = None
+opt_qconfigdir = None
 opt_sipbindir = None
 opt_sipmoddir = None
 opt_sipincdir = None
@@ -97,11 +98,12 @@ def usage(rcode = 2):
     rcode is the return code passed back to the calling process.
     """
     print "Usage:"
-    print "    python configure.py [-h] [-a] [-b dir] [-d dir] [-e dir] [-k] [-l Qt-library] [-p platform] [-u] [-v dir] [-x] option=value option+=value ..."
+    print "    python configure.py [-h] [-a] [-b dir] [-c dir] [-d dir] [-e dir] [-k] [-l Qt-library] [-p platform] [-u] [-v dir] [-x] option=value option+=value ..."
     print "where:"
     print "    -h             display this help message"
     print "    -a             export all symbols (pre SIP v4.2 behaviour) [default disabled]"
     print "    -b dir         where the SIP code generator will be installed [default %s]" % opt_sipbindir
+    print "    -c dir         where the Qt qconfig.h file can be found [default Qt include directory]"
     print "    -d dir         where the SIP module will be installed [default %s]" % opt_sipmoddir
     print "    -e dir         where the SIP header file will be installed [default %s]" % opt_sipincdir
     print "    -k             build the SIP module as a static library"
@@ -372,10 +374,15 @@ def check_qt_installation(macros):
     global qt_edition
 
     if qt_version >= 0x030000:
-        qconfig = os.path.join(qt_incdir, "qconfig.h")
+        if opt_qconfigdir:
+            qconfigdir = opt_qconfigdir
+        else:
+            qconfigdir = qt_incdir
+
+        qconfig = os.path.join(qconfigdir, "qconfig.h")
 
         if not os.access(qconfig,os.F_OK):
-            siputils.error("qconfig.h could not be found in %s." % qt_incdir)
+            siputils.error("qconfig.h could not be found in %s." % qconfigdir)
 
         f = open(qconfig)
         l = f.readline()
@@ -708,7 +715,7 @@ def create_makefiles():
     sipconfig.ParentMakefile(
         configuration=cfg,
         subdirs=["sipgen", "siplib"],
-        installs=("sipconfig.py", cfg.sip_mod_dir)
+        installs=(["sipconfig.py", "sipdistutils.py"], cfg.sip_mod_dir)
     ).generate()
 
     sipconfig.inform("Creating sip code generator Makefile...")
@@ -776,12 +783,13 @@ def main(argv):
     set_defaults()
 
     try:
-        optlist, args = getopt.getopt(argv[1:], "hab:d:e:kl:p:uv:x")
+        optlist, args = getopt.getopt(argv[1:], "hab:c:d:e:kl:p:uv:x")
     except getopt.GetoptError:
         usage()
 
     global qt_dir, opt_sipbindir, opt_sipmoddir, opt_sipincdir, opt_sipsipdir
     global opt_platform, opt_qtlib, opt_static, opt_debug, opt_export_all
+    global opt_qconfigdir
 
     for opt, arg in optlist:
         if opt == "-h":
@@ -790,6 +798,8 @@ def main(argv):
             opt_export_all = 1
         elif opt == "-b":
             opt_sipbindir = os.path.abspath(arg)
+        elif opt == "-c":
+            opt_qconfigdir = os.path.abspath(arg)
         elif opt == "-d":
             opt_sipmoddir = os.path.abspath(arg)
         elif opt == "-e":
